# nestifydict
A tool for parsing structured data in the form of dictionaries

Please see our [Documentation](https://nestifydict.readthedocs.io/en/latest/), 
[Github source code](https://github.com/jaredjbeard/nestifydict), 
and install from [PyPi](https://pypi.org/project/nestifydict/)

Please note, I am still testing, this. I deployed a bit early, so apologies for any bugs. They should be gone in a few days before the start of 2023.

Citation
--------
If you are using this in your work, please cite as

```
@misc{beard2022irl_gym,
    author = {Beard, Jared J.},
    title = {NestifyDict: A tool for parsing structured data},
    year = {2022},
    publisher = {GitHub},
    journal = {GitHub repository},
    howpublished = {\url{https://pypi.org/project/nestifydict/}},
}
```